//____________________________________________________________________________
/*!

\class   genie::EvtWrite

\brief   A class to write gSeaGen output in a EVT file

\author  Carla Distefano <distefano_c@lns.infn.it>
         LNS-INFN, Catania

\created May 22, 2012

\cpright  Copyright (c) 2012-2019, The KM3NeT Collaboration
          For the full text of the license see $GSEAGEN/LICENSE

*/
//____________________________________________________________________________

#ifndef _EVTWRITE_H__
#define _EVTWRITE_H__

#ifdef _ANTARES_ENABLED__


#include <cstdio>
#include <fstream>
#include <ctime>
#include <string>
#include <map>

#include <TSystem.h>
#include <TDatabasePDG.h>
#include <TGraph.h>

#include "io_gcc.hh"

#ifdef _GENIEVERSIONGTEQ3__
#include "Framework/Conventions/Constants.h"
#else
#include "Conventions/Constants.h"
#endif


#include "PropaMuon/PropaTracks.h"
#include "SeaEvent/GBinParam.h"
#include "SeaEvent/GSeaEvent.h"

using namespace std;
using namespace genie;

namespace genie {

class EvtWrite {

public :

  EvtWrite(GenParam * GenPar, bool OptPDG);
  EvtWrite(GenParam * GenPar, bool OptPDG, event * evt);

  ~EvtWrite();

  void                  WriteHeader(void);
  void                  WriteEvent(GSeaEvent * SeaEvt);


protected:


  event *               fEvt;
  ofstream              fOutFile;

  bool                  fNewEvt;

  GenParam *            fGenPar;

  TDatabasePDG *        fPdg;

  bool                  fOptPDG;


};
} // genie namespace



#endif
#endif // _GEVTWRITE_H__

