//____________________________________________________________________________
/*!

\class   PropaNucl

\brief   A class to compute muon energy loss: photo-nuclear 

\author  Carla Distefano <distefano_c@lns.infn.it>
         LNS-INFN, Catania

\created December 9, 2015

\cpright  Copyright (c) 2015-2019, The KM3NeT Collaboration 
          For the full text of the license see $GSEAGEN/LICENSE

*/
//____________________________________________________________________________


#ifndef _GPropaNucl_H__
#define _GPropaNucl_H__


#include <map>

#include <Math/IFunction.h>

using namespace std;

class PropaNucl {

public:
  PropaNucl();
  ~PropaNucl();
  
  double BCoeff (double Energy, double Z, double A);
  double BCoeff (double Energy, double Z, double A, double Vmin, double Vmax);
  double dE_dx  (double Energy, double Z, double A);
  double dE_dx  (double Energy, double Z, double A, double Vmin, double Vmax);

  double BCoeff (double Energy, map<int,double> MediaComposition);
  double BCoeff (double Energy, map<int,double> MediaComposition, double Vmin, double Vmax);
  double dE_dx  (double Energy, map<int,double> MediaComposition);
  double dE_dx  (double Energy, map<int,double> MediaComposition, double Vmin, double Vmax);

  double SigmaTot(double Energy, double Z, double A);
  double SigmaTot(double Energy, double Z, double A, double Vmin, double Vmax);

  double SigmaTot(double Energy, map<int,double> MediaComposition);  
  double SigmaTot(double Energy, map<int,double> MediaComposition, double Vmin, double Vmax);


  double Lambda(double Energy, map<int,double> MediaComposition);
  double Lambda(double Energy, map<int,double> MediaComposition, double Vmin, double Vmax);

  
  double Lambda(double Energy, double Z, double A);
  double Lambda(double Energy, double Z, double A, double Vmin, double Vmax);

};
//____________________________________________________________________________
          
class PropaNuclBCoeff : public ROOT::Math::IBaseFunctionOneDim
{
public:
  PropaNuclBCoeff(double Energy, double Z);
  ~PropaNuclBCoeff();
  
  // ROOT::Math::IBaseFunctionOneDim interface
   unsigned int                      NDim   (void)       const;
   double                            DoEval (double xin) const;
  ROOT::Math::IBaseFunctionOneDim * Clone  (void)       const;

private:
   double fEnergy;
   double fA;
};
//____________________________________________________________________________
          
class PropaNuclXSec : public ROOT::Math::IBaseFunctionOneDim
{
public:
  PropaNuclXSec(double Energy, double Z);
  ~PropaNuclXSec();
  // ROOT::Math::IBaseFunctionOneDim interface
   unsigned int                      NDim   (void)       const;
   double                            DoEval (double xin) const;
  ROOT::Math::IBaseFunctionOneDim * Clone  (void)       const;
private:
   double fEnergy;
   double fA;
};





#endif // _GPropaNucl_H__
