//____________________________________________________________________________
/*!

\class   PropaUtils

\brief   Utilities for PropaMuon class

\author  Carla Distefano <distefano_c@lns.infn.it>
         LNS-INFN, Catania

\created December 9, 2015

\cpright  Copyright (c) 2015-2019, The KM3NeT Collaboration
          For the full text of the license see $GSEAGEN/LICENSE
*/
//____________________________________________________________________________

#ifndef _PROPAUTILS_H__
#define _PROPAUTILS_H__

#include <cmath>


namespace propamuon {


  static const double kProtonMass     =  0.9382720;           // GeV
  static const double kElectronMass   =  0.0005109989;        // GeV
  static const double kMuonMass       =  0.105658357;         // GeV
  static const double kTauMass        =  1.77703;             // GeV

  static const double kElectronMass2  =  kElectronMass*kElectronMass; // GeV^2
  static const double kMuonMass2      =  kMuonMass*kMuonMass;     // GeV^2
  static const double kTauMass2       =  kTauMass*kTauMass;      // GeV^2

  static const double kMuonElectronMass =  kMuonMass/kElectronMass;

  static const double kMuonElectronMass2 =  kMuonElectronMass*kMuonElectronMass;


  static const double kAem   = 1./137.03599976;       // EM coupling const, dimensionless
  static const double kAem2  = kAem*kAem;
  static const double kAem3  = kAem*kAem*kAem;
  static const double kAem4  = kAem*kAem*kAem*kAem;


  static const double kPi    = 3.1415927;
  static const double ke     = 2.7182818;
  static const double kSqrte = sqrt(ke);

  static const double kNA    = 6.02214179E+23;
  static const double kLe    = 3.8616E-11;	// electron Compton wavelength cm
  static const double kLe2   = kLe*kLe;
  
  static const double kRe    = 2.8179403267E-13;       // cm




  int  PdgToZ      (int pdgc);
  int  PdgToA      (int pdgc);

}      // propamuon namespace

#endif // _PROPAUTILS_H__
