//____________________________________________________________________________
/*!

\class   genie::GSeaTrack

\brief   A class to store track info

\author  Carla Distefano <distefano_c@lns.infn.it>
         LNS-INFN, Catania
         Included modifications by Alfonso Garcia <alfonsog@nikhef.nl>
	 NIKHEF, Amsterdam (January 2019)

\created December 1, 2015

\cpright  Copyright (c) 2015-2019, The KM3NeT Collaboration
          For the full text of the license see $GSEAGEN/LICENSE

*/
//____________________________________________________________________________


#ifndef _GSEATRACK_H_
#define _GSEATRACK_H_

#include "TLorentzVector.h"

using namespace std;


class GSeaTrack : public TObject {

public :

  GSeaTrack();
  ~GSeaTrack();
  void Reset(void);
  void Set(uint32_t id, int16_t status, int32_t pdg, uint32_t motherid, float Mass, TLorentzVector * VecEne, TLorentzVector * VecPos, TLorentzVector * IntVer, float length, uint16_t gencounter, float pendepth);
  void SetStatus(int16_t status);
  void Translate(float X0, float Y0, float Z0);
  void Print();

  uint32_t  Id;                 ///< Unique track identifier
  int32_t   PdgCode;            ///< Pdg code
  uint32_t  MotherId;           ///< Mother unique identifier (up to ~2.14*10^9)
  int16_t   Status;             ///< Genie status propagation (+1000 if it is used for propagation)
  uint16_t  GenCounter;         ///< generation counter (CORSIKA-specific particle history information)
  double    E;                  ///< Energy
  double    V1;			///< Position: X coordinate
  double    V2;			///< Position: Y coordinate
  double    V3;           	///< Position: Z coordinate
  double    D1;			///< Direction cosine: X direction
  double    D2;			///< Direction cosine: Y direction
  double    D3;           	///< Direction cosine: Z direction
  double    T;                  ///< time [ns] of passage trough position
  float     Length;             ///< length travel by particle (relevant for propagated tracks)
  float     PenDepth;           ///< penetration depth [g/cm^2] (CORSIKA-specific)

protected :

  ClassDef(GSeaTrack,1);

};

#endif // _PEARTH_H_
