//____________________________________________________________________________
/*!

\class   genie::flux::GSeaAntaresFileFlux

\brief   A flux driver to read incident neutrinos from evt files

\author  Carla Distefano <distefano_c@lns.infn.it>
         LNS-INFN, Catania

\created March 18, 2019

\cpright  Copyright (c) 2019, The KM3NeT Collaboration
          For the full text of the license see $GSEAGEN/LICENSE

*/
//____________________________________________________________________________

#ifndef _GSEA_ANTARES_FILE_FLUX_I_H_
#define _GSEA_ANTARES_FILE_FLUX_I_H_

#ifdef _ANTARES_ENABLED__

#include "SeaNuDrivers/GSeaFileFlux.h"

#include "io_gcc.hh"

namespace genie {
namespace flux  {

class GSeaAntaresFileFlux: public GSeaFileFlux {

public :
  GSeaAntaresFileFlux(GenParam * GenPar);

 ~GSeaAntaresFileFlux();

 event * GetEvent(void){return fEvt;};

  //
  // Most implementation is derived from the base GSeaFileFlux
  // The concrete driver is only required to implement a function for
  // loading the input data files
  //


private:

  event *                 fEvt;

  ifstream                fInFile;

  void                    LoadHeaderFile        ();
  vector<GSeaTrack>       ReadFileEvent         (void);
  void                    ComputeWeights        (GSeaEvent * SeaEvt);

};

} // flux namespace
} // genie namespace


#endif // _ANTARES_ENABLED__
#endif // _GREAL_FILE_FLUX_I_H_
