//____________________________________________________________________________
/*!

\class   genie::flux::GSeaCORSIKAFileFlux

\brief   A flux driver to read incident muons and neutrinos from CORSIKA7 binary files

\author  Piotr Kalaczyński <piotr.kalaczynski@ncbj.gov.pl>
         NCBJ Warsaw

\created 25.12.2020

\cpright  Copyright (c) 2020, The KM3NeT Collaboration
          For the full text of the license see $GSEAGEN/LICENSE

*/
//____________________________________________________________________________

#ifndef _GSEA_CORSIKA_FILE_FLUX_I_H_
#define _GSEA_CORSIKA_FILE_FLUX_I_H_

#include "SeaNuDrivers/GSeaFileFlux.h"

namespace genie {
namespace flux  {

class GSeaCORSIKAFileFlux: public GSeaFileFlux {

public:
  GSeaCORSIKAFileFlux(GenParam * GenPar);
 ~GSeaCORSIKAFileFlux();
  
private:

  ifstream                CORSIKAFile;
  
  int32_t                 CorsikaToPdg          (int16_t CORSIKAId);
  double                  CorsikaRestMass       (int16_t CORSIKAId);
  double                  CRFlux                (double PrimEnergy, int16_t PrimCORSIKAId, string CRFluxModel);
  
  vector<GSeaTrack>       ReadFileEvent         (void);
  void                    ComputeWeights        (GSeaEvent * SeaEvt);
  void                    CustomRotation        (GSeaTrack *Track);

  // Declaration of parameters needed to read the CORSIKA files
  static const unsigned int   NRecStd = 22940;              // "standard CORSIKA" record size,
                                                            //        ThiData[0] = 6.08270e-311
                                                              //    or  ThiData[0] = 3.213456e-41
  static const unsigned int   NRecThi = 26216;                  // "thinning CORSIKA" record size,
                                                            //        ThiData[0] = 6.95166e-311
                                                              //    or  ThiData[0] = 3.672523e-41
  static const unsigned int   NumSubblocks = 21;            // number of subblocks per record
  static const unsigned int   LenSubblStd = 273;            // subblock length in words (standard)
  static const unsigned int   LenSubblThi = 312;            // subblock length in words (thinning)
  static const unsigned int   NumStd = 5735;                // =  NRecStd / 4
  static const unsigned int   NumThi = 6554;                // =  NRecThi / 4
  static const uint8_t        MaxNTracksPerSubblock = 39;
  
  unsigned int                LenSubblock, LBit, LThi,nShow,nRun,iRec,lp,PrimID;
  float                       MinEPrim,MaxEPrim,EPrim,EPrimSlope,sinSiteRot,cosSiteRot,HInt;
  bool                        FullEvent;

  // CORSIKA saves the output with single (float) precision
  float                      ThiData[NumThi];              // single corsika record thinned data
  float                      StdData[NumStd];              // single corsika record standard data
  float                      HData[819];                   // end of 1st corsika record thinned data
  float                      ZData[2];                     // record length info on 64bit machines
  
  // struct particle_data { // struct to hold secondary particle track information
  //   float ID;
  //   float MomentumX;
  //   float MomentumY;
  //   float MomentumZ;
  //   float PosXOrGenCount;
  //   float PosYOrPenDepth;
  //   float PosZOrTime;
  // };

};

} // flux namespace
} // genie namespace

#endif // _GREAL_FILE_FLUX_I_H_
