//____________________________________________________________________________
/*!

\class   genie::flux::GSaeRealAtmoFlux

\brief   A flux driver for the Atmospheric and Diffuse Neutrino Fluxes

\author  Carla Distefano <distefano_c@lns.infn.it>
         LNS-INFN, Catania

\created September 13, 2012

\cpright  Copyright (c) 2012-2019, The KM3NeT Collaboration
          For the full text of the license see $GSEAGEN/LICENSE

*/
//____________________________________________________________________________

#ifndef _GREAL_ATMO_FLUX_I_H_
#define _GREAL_ATMO_FLUX_I_H_



#include "SeaNuDrivers/GSeaAtmoFlux.h"

namespace genie {
namespace flux  {

class GSeaRealAtmoFlux: public GSeaAtmoFlux {

public :
  GSeaRealAtmoFlux(GenParam * GenPar);

 ~GSeaRealAtmoFlux();

  //
  // Most implementation is derived from the base GSeaAtmoFlux
  // The concrete driver is only required to implement a function for
  // loading the input data files
  //

private:

  void LoadFluxFile(void);

  void SetBinSizes              (string FluxSim, double Emin, double Emax);
  bool FillFluxHisto2D          (string FluxSim, TH2D * h2, string filename);
  bool FillBartolFlux           (TH2D * histo, string filename);
  bool FillFlukaFlux            (TH2D * histo, string filename);
  bool FillHondaFlux            (int NuType, TH2D * histo2D, TH3D * histo3D, string filename);

  FluxFunc2D ExtrapolateFlux    (TH2D * histo2D);


};

} // flux namespace
} // genie namespace

#endif // _GREAL_ATMO_FLUX_I_H_

