//____________________________________________________________________________
/*!

\library   matrix_operations

\brief   helper functions to perform some basic operations on 3x3 matrices

\author  Piotr Kalaczyński <piotr.kalaczynski@ncbj.gov.pl>
         NCBJ Warsaw

\created 16.03.2022

\cpright  Copyright (c) 2022, The KM3NeT Collaboration
          For the full text of the license see $GSEAGEN/LICENSE

*/
//____________________________________________________________________________

//___________________________________________________________________________
array<array<double,3>,3> InvertMatrix(const array<array<double,3>,3> &Matrix)
{
  // computes the inverse of Matrix
  // based on https://www.euclideanspace.com/maths/algebra/matrix/functions/inverse/threeD/index.htm
  
  double det = Matrix[0][0]*Matrix[1][1]*Matrix[2][2] + Matrix[0][1]*Matrix[1][2]*Matrix[2][0] + Matrix[0][2]*Matrix[1][0]*Matrix[2][1] - Matrix[0][0]*Matrix[1][2]*Matrix[2][1] - Matrix[0][1]*Matrix[1][0]*Matrix[2][2] - Matrix[0][2]*Matrix[1][1]*Matrix[2][0];

  array<array<double,3>,3> InvertedMatrix = {{
    { // first row
      (Matrix[1][1]*Matrix[2][2] - Matrix[1][2]*Matrix[2][1])/det,
      (Matrix[0][2]*Matrix[2][1] - Matrix[0][1]*Matrix[2][2])/det,
      (Matrix[0][1]*Matrix[1][2] - Matrix[0][2]*Matrix[1][1])/det,
    },
    { // second row
      (Matrix[1][2]*Matrix[2][0] - Matrix[1][0]*Matrix[2][2])/det,
      (Matrix[0][0]*Matrix[2][2] - Matrix[0][2]*Matrix[2][0])/det,
      (Matrix[0][2]*Matrix[1][0] - Matrix[0][0]*Matrix[1][2])/det,
    },
    { // third row
      (Matrix[1][0]*Matrix[2][1] - Matrix[1][1]*Matrix[2][0])/det,
      (Matrix[0][1]*Matrix[2][0] - Matrix[0][0]*Matrix[2][1])/det,
      (Matrix[0][0]*Matrix[1][1] - Matrix[0][1]*Matrix[1][0])/det,
    },
  }};
  
  return InvertedMatrix;
}
//___________________________________________________________________________
array<array<double,3>,3> MultiplyMatrices(const array<array<double,3>,3> &Matrix1, const array<array<double,3>,3> &Matrix2)
{
  
  array<array<double,3>,3> NewMatrix = {{
    { // first row
      Matrix1[0][0]*Matrix2[0][0] + Matrix1[0][1]*Matrix2[1][0] + Matrix1[0][2]*Matrix2[2][0],
      Matrix1[0][0]*Matrix2[0][1] + Matrix1[0][1]*Matrix2[1][1] + Matrix1[0][2]*Matrix2[2][1],
      Matrix1[0][0]*Matrix2[0][2] + Matrix1[0][1]*Matrix2[1][2] + Matrix1[0][2]*Matrix2[2][2],
    },
    {  // second row
      Matrix1[1][0]*Matrix2[0][0] + Matrix1[1][1]*Matrix2[1][0] + Matrix1[1][2]*Matrix2[2][0],
      Matrix1[1][0]*Matrix2[0][1] + Matrix1[1][1]*Matrix2[1][1] + Matrix1[1][2]*Matrix2[2][1],
      Matrix1[1][0]*Matrix2[0][2] + Matrix1[1][1]*Matrix2[1][2] + Matrix1[1][2]*Matrix2[2][2],
    },
    {  // third row
      Matrix1[2][0]*Matrix2[0][0] + Matrix1[2][1]*Matrix2[1][0] + Matrix1[2][2]*Matrix2[2][0],
      Matrix1[2][0]*Matrix2[0][1] + Matrix1[2][1]*Matrix2[1][1] + Matrix1[2][2]*Matrix2[2][1],
      Matrix1[2][0]*Matrix2[0][2] + Matrix1[2][1]*Matrix2[1][2] + Matrix1[2][2]*Matrix2[2][2],
    },
  }};
  return NewMatrix;
}
//___________________________________________________________________________
array<double,3> ApplyRotationMatrix(const array<double,3> &Vector, const array<array<double,3>,3> &RotMatrix)
{
  
  array<double,3> NewVector = {
    Vector[0]*RotMatrix[0][0] + Vector[1]*RotMatrix[0][1] + Vector[2]*RotMatrix[0][2],
    Vector[0]*RotMatrix[1][0] + Vector[1]*RotMatrix[1][1] + Vector[2]*RotMatrix[1][2],
    Vector[0]*RotMatrix[2][0] + Vector[1]*RotMatrix[2][1] + Vector[2]*RotMatrix[2][2],
  };
  
  return NewVector;
}
